@@ -36,6 +36,7 @@
 
 static long getSeconds(char *timestr);
 static int checkPageType(auctionInfo *aip, int pageType, int auctionState, int auctionResult);
+static int parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t start, int debugMode);
 
 static const char PRIVATE[] = "private auction - bidders' identities protected";
 
@@ -67,18 +68,8 @@ static const char PRIVATE[] = "private auction - bidders' identities protected";
 int
 parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirstByte, int debugMode)
 {
-	char *line;
-	char **row = NULL;
-	int ret = 0;		/* 0 = OK, 1 = failed */
-	int foundHeader = 0;	/* found bid history table header */
 	pageInfo_t *pp;
-	int pageType = 0;
-	int auctionState = 0;
-	int auctionResult = 0;
-	int got;
-	char *tmpPagename;
-	const char *delim = "_";
-	char *token;
+	int ret = 0;
 
 	resetAuctionError(aip);
 
@@ -86,50 +77,72 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		*timeToFirstByte = getTimeToFirstByte(mp);
 
 	if ((pp = getPageInfo(mp))) {
-		if (pp->srcId && !strcmp(pp->srcId, "Captcha.xsl"))
-			return auctionError(aip, ae_captcha, NULL);
-		if (pp->pageName && !strncmp(pp->pageName, "PageViewBids", 12)) {
-			pageType = VIEWBIDS;
-
-			tmpPagename = myStrdup(pp->pageName);
-			/* this must be PageViewBids */
-			token = strtok(tmpPagename, delim);
-			token = strtok(NULL, delim);
-			if(token != NULL)
-			{
-				if(!strcmp(token, "Active")) auctionState = STATE_ACTIVE;
-				else if(strcmp(token, "Closed")) auctionState = STATE_CLOSED;
-				token = strtok(NULL, delim);
-				if(token != NULL)
-				{
-					if(!strcmp(token, "None")) auctionResult = RESULT_NONE;
-					else if(!strcmp(token, "HighBidder")) auctionResult = RESULT_HIGH_BIDDER;
-				}
-			}
-
-			/* bid history or expired/bad auction number */
-			while ((line = getNonTag(mp))) {
-				if (!strcmp(line, "Bid History")) {
-					log(("parseBidHistory(): got \"Bid History\"\n"));
-					break;
-				}
-				if (!strcmp(line, "Unknown Item")) {
-					log(("parseBidHistory(): got \"Unknown Item\"\n"));
-					return auctionError(aip, ae_baditem, NULL);
-				}
-			}
-		} else if (pp->pageName && !strncmp(pp->pageName, "PageViewTransactions", 20)) {
-			/* transaction history -- buy it now only */
-			pageType = VIEWTRANSACTIONS;
-		} else if (pp->pageName && !strcmp(pp->pageName, "PageSignIn")) {
-			return auctionError(aip, ae_mustsignin, NULL);
-		} else {
-			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "unknown pagename");
-			return auctionError(aip, ae_notitle, NULL);
-		}
+		ret = parseBidHistoryInternal(pp, mp, aip, start, debugMode);
+		freePageInfo(pp);
 	} else {
 		log(("parseBidHistory(): pageinfo is NULL\n"));
 		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "pageInfo is NULL");
+		ret = auctionError(aip, ae_notitle, NULL);
+	}
+	return ret;
+}
+
+int
+parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t start, int debugMode)
+{
+	char *line;
+	char **row = NULL;
+	int ret = 0;		/* 0 = OK, 1 = failed */
+	int foundHeader = 0;	/* found bid history table header */
+	int pageType = 0;
+	int auctionState = 0;
+	int auctionResult = 0;
+	int got;
+	const char *delim = "_";
+
+
+
+	if ((pp->srcId && !strcmp(pp->srcId, "Captcha.xsl")) ||
+		(pp->pageName && !strncmp(pp->pageName, "Security Measure", 16)))
+		return auctionError(aip, ae_captcha, NULL);
+	if (pp->pageName && !strncmp(pp->pageName, "PageViewBids", 12)) {
+		char *tmpPagename = myStrdup(pp->pageName);
+		char *token;
+
+		pageType = VIEWBIDS;
+
+		/* this must be PageViewBids */
+		token = strtok(tmpPagename, delim);
+		token = strtok(NULL, delim);
+		if (token != NULL) {
+			if(!strcmp(token, "Active")) auctionState = STATE_ACTIVE;
+			else if(strcmp(token, "Closed")) auctionState = STATE_CLOSED;
+			token = strtok(NULL, delim);
+			if (token != NULL) {
+				if(!strcmp(token, "None")) auctionResult = RESULT_NONE;
+				else if(!strcmp(token, "HighBidder")) auctionResult = RESULT_HIGH_BIDDER;
+			}
+		}
+		free(tmpPagename);
+
+		/* bid history or expired/bad auction number */
+		while ((line = getNonTag(mp))) {
+			if (!strcmp(line, "Bid History")) {
+				log(("parseBidHistory(): got \"Bid History\"\n"));
+				break;
+			}
+			if (!strcmp(line, "Unknown Item")) {
+				log(("parseBidHistory(): got \"Unknown Item\"\n"));
+				return auctionError(aip, ae_baditem, NULL);
+			}
+		}
+	} else if (pp->pageName && !strncmp(pp->pageName, "PageViewTransactions", 20)) {
+		/* transaction history -- buy it now only */
+		pageType = VIEWTRANSACTIONS;
+	} else if (pp->pageName && !strcmp(pp->pageName, "PageSignIn")) {
+		return auctionError(aip, ae_mustsignin, NULL);
+	} else {
+		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "unknown pagename");
 		return auctionError(aip, ae_notitle, NULL);
 	}
 
@@ -385,32 +398,6 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 	 *	    If the auction is private, the user names are:
 	 *		"private auction - bidders' identities protected"
 	 *
-	 *	Dutch auction:
-	 *	    Header line:
-	 *		""
-	 *		"Bidder"
-	 *		"Bid Amount"
-	 *		"Qty Wanted"
-	 *		"Qty Winning"
-	 *		"Bid Time"
-	 *		""
-	 *
-	 *	    For each bid:
-	 *			""
-	 *			<user>
-	 *			<price>
-	 *			<quantity wanted>
-	 *			<quantity winning>
-	 *			<date>
-	 *			""
-	 *	    (plus multiple rows of 1 column between entries)
-	 *
-	 *	    If there are no bids:
-	 *			""
-	 *			"No bids have been placed."
-	 *
-	 *	    Dutch auctions cannot be private.
-	 *
 	 *	If there are no bids, the text "No bids have been placed."
 	 *	will be the first entry in the table.  If there are bids,
 	 *	the last bidder might be "Starting Price", which should
@@ -609,57 +596,6 @@ parseBidHistory(memBuf_t *mp, auctionInfo *aip, time_t start, time_t *timeToFirs
 		free(winner);
 		break;
 	    }
-	case 7: /* dutch with bids */
-	    {
-		int wanted = 0;
-		char *currently = NULL;
-
-		aip->bids = 0;
-		aip->quantityBid = 0;
-		aip->won = 0;
-		aip->winning = 0;
-		/* find your bid, count number of bids */
-		/* blank, user, price, wanted, winning, date, blank */
-		for (; row; row = getTableRow(mp)) {
-			if (numColumns(row) == 7) {
-				int bidderWinning = getIntFromString(row[4]);
-
-				++aip->bids;
-				if (bidderWinning > 0) {
-					char *bidder;
-
-					aip->quantityBid += bidderWinning;
-					free(currently);
-					bidder = getNonTagFromString(row[1]);
-					currently = getNonTagFromString(row[2]);
-					if (!strcasecmp(bidder, options.username)) {
-						wanted = getIntFromString(row[3]);
-						aip->winning = bidderWinning;
-					}
-					free(bidder);
-				}
-			}
-			freeTableRow(row);
-		}
-		if (!aip->remain)
-			aip->won = aip->winning;
-		printf("# of bids: %d\n", aip->bids);
-		printf("Currently: %s  (your maximum bid: %s)\n",
-			currently, aip->bidPriceStr);
-		free(currently);
-		if (aip->winning > 0) {
-			if (aip->winning == wanted)
-				printLog(stdout, "High bidder: %s!!!\n", options.username);
-			else
-				printLog(stdout, "High bidder: %s!!! (%d out of %d items)\n", options.username, aip->winning, wanted);
-		} else {
-			if (*options.username)
-				printLog(stdout, "High bidder: various dutch bidders (NOT %s)\n", options.username);
-			else
-				printLog(stdout, "High bidder: various dutch bidders\n");
-		}
-		break;
-	    }
 	default:
 		if (checkPageType(aip, pageType, auctionState, auctionResult) != 0)
 		{
